<?php
/***************************************************************
*  Copyright notice
*
*  (c) 2008 Mario Haim (mario@bramble-it.com)
*  All rights reserved
*
*  This script is part of the TYPO3 project. The TYPO3 project is
*  free software; you can redistribute it and/or modify
*  it under the terms of the GNU General Public License as published by
*  the Free Software Foundation; either version 2 of the License, or
*  (at your option) any later version.
*
*  The GNU General Public License can be found at
*  http://www.gnu.org/copyleft/gpl.html.
*
*  This script is distributed in the hope that it will be useful,
*  but WITHOUT ANY WARRANTY; without even the implied warranty of
*  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
*  GNU General Public License for more details.
*
*  This copyright notice MUST APPEAR in all copies of the script!
***************************************************************/
/**
 * Plugin 'SQL Frontend' for the 'mh_omsqlio' extension.
 *
 * @author	Mario Haim <mario@bramble-it.com>
 */

//needed for overlib and image rising callback functions
$GLOBALS['TSFE']->setJS('openPic');
if(t3lib_extMgm::isLoaded('overlib')) {
	include_once(t3lib_extMgm::extPath('overlib').'class.tx_overlib.php');
	tx_overlib::includeLib();
}

class tx_mhomsqlio_callback {
	var $oParent;
	function tx_mhomsqlio_callback(&$_oParent) {
		$this->oParent =& $_oParent;
	}
/**
 **	----- MH_OMSQLIO CALLBACK FUNCTIONS -----
		
 *	DEFINITION
	- IN: one parameter (the current value)
	- OUT: two parameters (the current value and a boolean if it's csv (true if CSV)
	- string return (the new value)
	
 *	NOTES
	- values get prepared for output BEFORE calling the callback function (so HTML code stays in HTML code)
	- values get prepared for input AFTER calling the callback function (in order to prevent SQL injections)
	- $this->oParent holds an instance of mh_omsqlio (maybe useful for tslib_pibase calls, e.g. $this->oParent->pi_getPageLink(...))
	- callback function WON'T be called when preparing the output for editing/adding
*/



/**
*******	INWARDS
**/

	/**
	* prepare a phone number for a numeric field
	* @param	string	anything the user inserted
	* @param	string	a nicely formatted phone number
	**/
	function in_phone($_sValue) {
		return str_replace(array(' ', '/'), '', str_replace('+', '00', $_sValue));
	}
	
	/**
	* based on various user settings find the best distribution list in a magazine administration system
	* @param	integer	id of first distribution list (in order to know the mag name)
	* @return	integer	the distribution list id to use
	**/
	function in_findDistributionList($_nValue) {
		if($oResult = $this->oParent->oDb->execute('SELECT a.nDisId, b.nUid, tx_mhomplan_building, tx_mhomplan_roomnumber, tx_dpomem_group FROM mag_distribution a
			LEFT JOIN mag_abonnement b ON (a.nDisId = b.nDisId AND b.bDeleted = 0) LEFT JOIN fe_users c ON (b.nUid = c.uid AND c.deleted = 0 AND c.disable = 0)
			WHERE a.bDeleted = 0 AND a.sName = (SELECT sName FROM mag_distribution WHERE nDisId = '.intval($_nValue).' LIMIT 1) ORDER BY a.nDisId')) {
			$aDist = array();
			while($aRow = $this->oParent->oDb->get($oResult)) {
				if(!array_key_exists($aRow['nDisId'], $aDist)) $aDist[$aRow['nDisId']] = array(10000, 0);	//create array for this distribution list containing all points (10000) and number of employees (0)
				if(!is_null($aRow['nUid'])) {	//only if a user for this distribution list exists
					if($aRow['tx_mhomplan_building'] != $GLOBALS['TSFE']->user->fe_user['tx_mhomplan_building']) $aDist[$aRow['nDisId']][0] -= 5000;	//different building
					if($aRow['tx_mhomplan_roomnumber']{0} != $GLOBALS['TSFE']->user->fe_user['tx_mhomplan_roomnumber']{0}) $aDist[$aRow['nDisId']][0] -= 500;	//different floor
					if($aRow['tx_dpomem_group'] != $GLOBALS['TSFE']->user->fe_user['tx_dpomem_group']) $aDist[$aRow['nDisId']][0] -= 50;	//different group
					$aDist[$aRow['nDisId']][1]++;	//add user to amount of users
				}
			}
			if(count($aDist) <= 0) return $_nValue;
			else {
				$aBest = array();
				foreach($aDist as $nDisId => $aStat) {
					if($aStat[1] >= 15) $aDist[$nDisId][0] -= 10000;	//check if distribution list is full (15 persons)
					if($aDist[$nDisId][0] > $aBest[1][0] || !isset($aBest[0])) $aBest = array($nDisId, $aDist[$nDisId]);
				}
				return $aBest[0];
			}
		} else return $_nValue;
	}



/**
*******	OUTWARDS
**/

	/**
	* convert a telephone number into a cisco call manager link
	* @param	string	phone number in format +43 12234 134123 123
	* @param	boolean	true if output is prepared for CSV file, otherwise false
	* @return	string	link with current phone number as link but linked to the call manager without spaces and + replaced with 00 - also a leading 0 is appended
	**/
	function out_linkCcm($_sValue, $_bCsv = false) {
		if($_bCsv === true) return $_sValue;
		if($_sValue == '') $_sValue = $this->oParent->getEmptyCell();
		return '<a href="https://verona.omicron.at/webdialer/Webdialer?destination=0'.$this->in_phone($_sValue).'" target="_blank">'.$_sValue.'</a>';
	}

	/**
	* create a "locate" link with mh_omroomplan extension
	* @param	string	location and room number splitted with a underscore
	* @param	boolean	true if output is prepared for CSV file, otherwise false
	* @return	string	the complete locate link
	**/
	function out_linkLocate($_sValue, $_bCsv = false) {
		if($_sValue != '') {
			list($sLoc, $nRoom) = explode('_', $_sValue);
			if($_bCsv === true) return $nRoom;
			if($sLoc != '' && $nRoom > 0) {
				include_once(t3lib_extMgm::extPath('mh_omroomplan').'pi1/class.tx_mhomroomplan_pi1.php');
				$oRoom = t3lib_div::makeInstance('tx_mhomroomplan_pi1');
				return $oRoom->getLocateLink($this->oParent, $sLoc, $nRoom);
			} else return '';
		} else return '';
	}

	/**
	* check wether a certain image exists, otherwise use a shadow picture
	* @param	string	image file name or empty if non
	* @param	boolean	true if output is prepared for CSV file, otherwise false
	* @return	string	img-tag surrounded with a link for large view
	**/
	function out_imgCheck($_sValue, $_bCsv = false, $_bNoPlaceholder = false) {
		$aTsConf = array('limit' => 1, 'file.' => array('width' => 100), 'imageLinkWrap' => 1, 'imgWrap.' => array('wrap' => '|'), 'allWrap.' => array('wrap' => '|'), 'imageLinkWrap.' =>
			array('enable' => 1, 'bodyTag' => '<body bgColor="black">', 'wrap' => '<a href="javascript:close();"> | </a>', 'width' => '800m', 'height' => '600', 'JSwindow' => 1,
			'JSwindow.' => array('newWindow' => 1, 'expand' => '17,20')));
    	$content = '';
		$aPath = array('uploads/pics/', 'fileadmin/user-upload/images/employees/');
		$aImages = t3lib_div::trimExplode(',', $_sValue);
		for($i = 0; $i < count($aImages); $i++) {
			if((file_exists($aPath[0].$aImages[$i]) || file_exists($aPath[1].$aImages[$i])) && $i < $aTsConf['limit']) {
			    $aTsConf['file'] = (file_exists($aPath[0].$aImages[$i]) ? ($aPath[0].$aImages[$i]) : ($aPath[1].$aImages[$i]));
				$content .= $this->oParent->cObj->stdWrap($this->oParent->cObj->IMAGE($aTsConf), $aTsConf['imgWrap.']);
			}
		}
		if($_bNoPlaceholder) return $content;
		elseif($content == '') {
			if(file_exists($aPath[0].'Placeholder.gif')) {
				$aTsConf['file'] = $aPath[0].'Placeholder.gif';
				return $this->oParent->cObj->stdWrap($this->oParent->cObj->IMAGE($aTsConf), $aTsConf['imgWrap.']);
			} else return '';
		} else return $content;
	}
	

	/**
	* create first name with overlib-hover effect for previewing an image of the person
	* @param	string	firstname, username, uid and image as one string - separated with an underscore
	* @param	boolean	true if output is prepared for CSV file, otherwise false
	* @return	string	first name as a link to the employee directory using the uid and a hover effect that popups the image in an overlay box
	**/
	function out_nameHoverImg($_sValue, $_bCsv = false) {
		list($sFirst, $sUser, $nUid, $sImage) = explode('_', $_sValue, 4);
		if($_bCsv === true) return $sFirst;
		$sImage = $this->out_imgCheck($sImage, $_bCsv, true);
		$sLink = 'index.php?id=195&no_cache=1&tx_mhomemdir_pi1[backPid]='.$GLOBALS['TSFE']->id.'&tx_mhomemdir_pi1[uid]='.$nUid;
		if(t3lib_extMgm::isLoaded('overlib') && $sImage != '') return '<a href="'.$sLink.'" onclick="javascript: document.location.href = \''.
			$sLink.'\'; return false;" onmouseover="return overlib.ov(\''.t3lib_div::slashJS(htmlentities($sImage), true).'\', CAPTION, \''.
			t3lib_div::slashJS($sUser, true).'\');" onmouseout="return overlib.nd();">'.nl2br($sFirst).'</a>';
		else return '<a href="'.$sLink.'" onclick="javascript: document.location.href = \''.$sLink.'\'; return false;">'.nl2br($sFirst).'</a>';
	}
	
	/**
	* hide content behind icon (no icon if no content) and display an icon for editing
	* @param	string	id and comment separated with a double point
	* @param	boolean	true if output is prepared for CSV file, otherwise false
	* @return	string	currently crap
	**/
	function out_presentComment($_sValue, $_bCsv = false) {
		list($nEleId, $sComment) = explode('-', $_sValue, 2);
		if($_bCsv === true) return $sComment;
		if($sComment != '') $sComment = '<span id="tx_mhomsqlio_event-'.$nEleId.'" style="display: none;">'.$sComment.'</span><img src="typo3conf/ext/mh_omsqlio/'.
			'res/eye.gif" alt="Toggle comment" title="Toggle comment" style="cursor: pointer;" onclick="javascript: tx_mhomsqlio_toggle(\''.
			'tx_mhomsqlio_event-'.$nEleId.'\'); return false;" />&nbsp;&nbsp;';
		return $sComment.'<a href="#" onclick="javascript: tx_mhomsqlio_edit(\''.$this->oParent->sContElem.'\', this); return false;">'.
			'<img src="typo3conf/ext/mh_omsqlio/res/edit_comment.gif" alt="Edit comment" title="Edit comment" /></a>';
	}
	
	/**
	* similar to $this->out_presentComment, but with two fields
	* @param	string	id, title and description separated with string %_%
	* @param	boolean	true if output is prepared for CSV file, otherwise false
	* @return	string	title and an eye icon behind it if description is not empty
	**/
	function out_showTitleHideDesc($_sValue, $_bCsv = false) {
		list($nId, $sTitle, $sDesc) = explode('%_%', $_sValue, 3);
		if($_bCsv === true) return $sTitle;
		$nId = intval($nId);
		if($sDesc != '') $sDesc = '<span id="tx_mhomsqlio_desc-'.$nId.'" style="display: none;">'.$sDesc.'</span>'.
			'&nbsp;<img src="typo3conf/ext/mh_omsqlio/res/eye.gif" alt="Toggle description" title="Toggle description" '.
			'style="cursor: pointer;" onclick="javascript: tx_mhomsqlio_toggle(\'tx_mhomsqlio_desc-'.$nId.'\'); return false;" />';
		return $sTitle.$sDesc;
	}
}

?>